

set -ex



test -f $PREFIX/lib/libjemalloc.so.2
test ! -f $PREFIX/lib/libjemalloc.a
test ! -f $PREFIX/lib/libjemalloc_pic.a
test -f $PREFIX/include/jemalloc/jemalloc.h
$CC -I$PREFIX/include -L$PREFIX/lib -ljemalloc test.c
exit 0
